/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.json.authentication;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;

/**
 * {@link GuardAuthenticationFactory} creates OX Guard specific authentication tokens from given HTTP requests.
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v7.8.3
 */
public class GuardAuthenticationFactory implements CryptographicServiceAuthenticationFactory {

    public static final String VALUE_DELIMITER = ":";
    private static final String AUTH_TOKEN_PARAMETER_NAME = "cryptoAuth";
    private static final Object GUARD_AUTH_COOKIE_NAME = "cryptoAuth";
    private static final Object GUARD_SESSION_COOKIE_NAME = "JSESSIONID";

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.file.storage.json.crypto.EncryptionServiceAuthenticationFactory#createAuthenticationFrom(javax.servlet.http.HttpServletRequest)
     */
    @Override
    public String createAuthenticationFrom(HttpServletRequest request) {

        String sessionValue = null;
        String authToken = null;

        Cookie[] cookies = request.getCookies();
        if (cookies != null) {
            for (Cookie cookie : cookies) {
                if (cookie.getName().equals(GUARD_SESSION_COOKIE_NAME)) {
                    sessionValue = cookie.getValue();
                } else if (cookie.getName().equals(GUARD_AUTH_COOKIE_NAME)) {
                    authToken = cookie.getValue();
                }
            }
        }

        if (authToken == null) {
            authToken = request.getParameter(AUTH_TOKEN_PARAMETER_NAME);
        }

        if (sessionValue != null && authToken != null && !authToken.equals("null")) {
            return sessionValue + VALUE_DELIMITER + authToken;
        }
        return null;
    }
}
